test_logics Package
===================

:mod:`test_author` Module
-------------------------

.. automodule:: permission.tests.test_logics.test_author
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_base` Module
-----------------------

.. automodule:: permission.tests.test_logics.test_base
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_collaborators` Module
--------------------------------

.. automodule:: permission.tests.test_logics.test_collaborators
    :members:
    :undoc-members:
    :show-inheritance:

